==> org.apache.sling.feature.cpconverter-1.1.20-source-release.zip: org.apache.sling.feature.cpconverter-1.1.20/src/test/java/org/apache/sling/feature/cpconverter/handlers/AbstractConfigurationEntryHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.sling.feature.cpconverter.handlers;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

public class AbstractConfigurationEntryHandlerTest {

    @Test public void testExtractId() {
        assertEquals("org.apache.sling.Component", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component"));
        assertEquals("org.apache.sling.Component", AbstractConfigurationEntryHandler.extractId("apath/org.apache.sling.Component"));
        assertEquals("org.apache.sling.Component~factory", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component~factory"));
        assertEquals("org.apache.sling.Component~factory", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component-factory"));
    }
}

==> org.apache.sling.feature.cpconverter-1.3.10-source-release.zip: org.apache.sling.feature.cpconverter-1.3.10/src/test/java/org/apache/sling/feature/cpconverter/handlers/AbstractConfigurationEntryHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.sling.feature.cpconverter.handlers;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

public class AbstractConfigurationEntryHandlerTest {

    @Test public void testExtractId() {
        assertEquals("org.apache.sling.Component", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component"));
        assertEquals("org.apache.sling.Component", AbstractConfigurationEntryHandler.extractId("apath/org.apache.sling.Component"));
        assertEquals("org.apache.sling.Component~factory", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component~factory"));
        assertEquals("org.apache.sling.Component~factory", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component-factory"));
        assertEquals("org.apache.sling.Component~factory-a", AbstractConfigurationEntryHandler.extractId("org.apache.sling.Component~factory-a"));
    }
}
